@@ -6,10 +6,16 @@
 import enum
 import functools
 
-from w8_auto_py.typings import ArgsType, Function, NumberTypes, KwargsType
+from w8_auto_py.typings import ArgsType, Function, KwargsType, NumberTypes, PoolExecutorTypes
 from w8_auto_py.global_vars import TimeUnit
-from w8_auto_py.common.emitter import AbstractEmitter, EmitterReturnType, Emitter, EmitterGroup, EmitterQueue, \
-    EmitterCollection
+from w8_auto_py.common.emitter import (
+    AbstractEmitter,
+    Emitter,
+    EmitterCollection,
+    EmitterGroup,
+    EmitterReturnType,
+    EmitterQueue
+)
 from w8_auto_py.common.runner import create_arunner, run
 from w8_auto_py.util import EnumUtil
 
@@ -23,95 +29,96 @@ class Emitters(enum.Enum):
 class EmitterFactory:
 
     @classmethod
-    def create_task(cls, max_num: int) -> EmitterQueue:
-        return EmitterQueue(max_len=max_num)
+    def create_task(cls, max_len: int) -> EmitterQueue:
+        return EmitterQueue(max_len=max_len)
 
     @classmethod
     def _factory(cls,
                  emitters: Emitters,
                  delay: NumberTypes = 500,
-                 date_unit: TimeUnit = TimeUnit.MS,
+                 time_unit: TimeUnit = TimeUnit.MS,
                  **kwargs) -> AbstractEmitter:
-        if not isinstance(emitters, Emitters):
-            raise TypeError("results must be EmitterResults Enum")
-
+        klass = EnumUtil.get_enum_value(emitters)
         f = functools.partial(
-            EnumUtil.get_enum_value(emitters),
+            klass,
             delay=delay,
-            date_unit=date_unit
+            time_unit=time_unit
         )
         return f(**kwargs)
 
     @classmethod
     def create(cls,
                emitters: Emitters,
+               task: EmitterQueue,
                delay: NumberTypes = 500,
-               date_unit: TimeUnit = TimeUnit.MS,
-               max_num: int = None,
+               time_unit: TimeUnit = TimeUnit.MS,
                **kwargs) -> AbstractEmitter:
-        task = cls.create_task(max_num)
         return cls._factory(
             emitters=emitters,
             task=task,
             delay=delay,
-            date_unit=date_unit,
+            time_unit=time_unit,
             **kwargs
         )
 
 
-def create_emitter(coro_func: Function,
+def create_emitter(coro_or_func: Function,
                    args: ArgsType = None,
                    kwargs: KwargsType = None,
-                   max_num: int = None,
+                   executor: PoolExecutorTypes = None,
                    delay: NumberTypes = 500,
-                   date_unit: TimeUnit = TimeUnit.MS) -> Emitter:
+                   max_len: int = None,
+                   time_unit: TimeUnit = TimeUnit.MS) -> Emitter:
+    """
+    创建并发器
+    :param coro_or_func:
+    :param args:
+    :param kwargs:
+    :param executor:
+    :param delay:
+    :param max_len:
+    :param time_unit:
+    :return:
     """
-    创建 并发器
-    Args:
-        coro_func:
-        args:
-        kwargs:
-        max_num:
-        delay:
-        date_unit:
-    Returns:
 
-    """
+    task = EmitterFactory.create_task(max_len)
     return EmitterFactory.create(
         emitters=Emitters.EMITTER,
-        coro_func=coro_func,
+        coro_or_func=coro_or_func,
+        task=task,
         delay=delay,
-        date_unit=date_unit,
-        max_num=max_num,
+        max_len=max_len,
+        time_unit=time_unit,
         args=args,
         kwargs=kwargs,
+        executor=executor
     )
 
 
-def emitter_decorator(max_num: int = None,
+def emitter_decorator(max_len: int = None,
                       delay: NumberTypes = 500,
-                      date_unit: TimeUnit = TimeUnit.MS) -> Emitter:
+                      time_unit: TimeUnit = TimeUnit.MS,
+                      executor: PoolExecutorTypes = None) -> Emitter:
     """
     并发包装器
-    Args:
-        max_num:
-        delay:
-        date_unit:
-
-    Returns:
-
+    :param max_len:
+    :param delay:
+    :param time_unit:
+    :param executor:
+    :return:
     """
 
-    def _decorate(func: Function):
-        @functools.wraps(func)
+    def _decorate(coro_or_func: Function):
+        @functools.wraps(coro_or_func)
         def _wrapper(*args, **kwargs) -> Emitter:
             return create_emitter(
-                coro_func=func,
+                coro_or_func=coro_or_func,
                 delay=delay,
-                date_unit=date_unit,
-                max_num=max_num,
+                max_len=max_len,
+                time_unit=time_unit,
                 args=args,
-                kwargs=kwargs
+                kwargs=kwargs,
+                executor=executor
             )
 
         return _wrapper
@@ -119,44 +126,47 @@ def emitter_decorator(max_num: int = None,
     return _decorate
 
 
-def create_emitter_group(max_num: int = None,
+def create_emitter_group(max_len: int = None,
                          delay: NumberTypes = 500,
-                         date_unit: TimeUnit = TimeUnit.MS) -> EmitterGroup:
+                         time_unit: TimeUnit = TimeUnit.MS) -> EmitterGroup:
     """
     创建 并发组
     Args:
-        max_num:
+        max_len:
         delay:
-        date_unit:
+        time_unit:
 
     Returns:
 
     """
-
+    task = EmitterFactory.create_task(max_len)
     return EmitterFactory.create(
         emitters=Emitters.EMITTER_GROUP,
+        task=task,
         delay=delay,
-        date_unit=date_unit
+        time_unit=time_unit
     )
 
 
-def create_emitter_collection(max_num: int = None,
+def create_emitter_collection(max_Len: int = None,
                               delay: NumberTypes = 500,
-                              date_unit: TimeUnit = TimeUnit.MS) -> EmitterCollection:
+                              time_unit: TimeUnit = TimeUnit.MS) -> EmitterCollection:
     """
     创建 并发集合
     Args:
-        max_num:
+        max_Len:
         delay:
-        date_unit:
+        time_unit:
 
     Returns:
 
     """
+    task = EmitterFactory.create_task(max_Len)
     return EmitterFactory.create(
         emitters=Emitters.EMITTER_COLLECTION,
+        task=task,
         delay=delay,
-        date_unit=date_unit
+        time_unit=time_unit
     )
 
 
